@@ -50,7 +50,7 @@ def init(args):
        		   		   v0.0.1""")
     
     if len(args) > 0:
-        print('INIT ERROR: attempting nwborglab initialization from file')
+        print('attempting nwborglab initialization from file ' + args[0])
         if not os.path.isfile(args[0]):
             print(args[0] + ' no such file :(')
         if not args[0].endswith('.nwb'):
@@ -65,7 +65,7 @@ def init(args):
         session_skeleton_sapofto = SAPOFTO.SAPOFTO('SKELETONS',nwbfile_in.get_scratch('nwborglab_session_skeleton'))
         #session_skeleton_sapofto = nwbfile_in.get_scratch('nwborglab_session_source_code')
         
-        SAPOFTO.recursiveFolderWrite(os.getcwd(), safe_mode=True)
+        SAPOFTO.recursiveFolderWrite(sensors_sapofto, os.getcwd(), safe_mode=True)
         return
     
     tab = '    '
